import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Diese Klasse Repräsentiert das Feld, auf dem sich die Schafe bewegen. 
 * 
 * Hier muss man nichts ändern
 */
public class Field extends World
{

    // Breite des Feldes.
    public static final int FLD_WID = 50;

    // Höhe des Feldes.
    public static final int FLD_HGH = 38;

 
    /**
     * Konstruktor.
     */
    public Field()
    {    
        // Erstellt die Welt in der angegebenen Höhe und Breite
        super(FLD_WID, FLD_HGH, 24); 

        // Fügt in die oberen drei Reihen Mauern hinzu
        for (int i=0;i < 3 ;++i) {
            for (int j= 0; j < FLD_WID; ++j) {
                Brick bTemp = new Brick();
                addObject(bTemp, j,i);
            }
        }

        // Fügt Mauern an den linken und rechten Rändern hinein.
        for (int j=1; j < FLD_HGH; ++j) {
            Brick bTemp = new Brick();
            addObject(bTemp, 0, j);

            bTemp = new Brick();
            addObject(bTemp, FLD_WID-1,j);

        }
        
        // Fügt eine Mauer in der letzten Reihe (unten) hinzu.
        for (int j= 0; j < FLD_WID; ++j) {
            Brick bTemp = new Brick();
            addObject(bTemp, j,FLD_HGH-1);
        }
        
        // Verteilt das Gras auf dem ganzen Feld
        for (int i=3;i < 37 ;++i) {
            for (int j= 1; j < FLD_WID -1; ++j) {
                Grass grass= new Grass();
                addObject(grass, j,i);
            }
        }
      
        // Bereite das Feld for mit dem Greenfoot Interface
        prepare();
    }

    /**
     * Diese Methode überprüft ob ein bestimmtes Feld leer ist:
     *  x - x-index auf der x Achse im Zellenformat.
     *  y - y-index auf der y Achse im Zellenformat.
     *  
     *  Output : Ein Boolean ob das Feld besetzt ist oder nicht.
     *  true  - leer
     *  false - besetzt
     */
    public boolean isEmpty(int x, int y)
    {   
        java.util.List lTemp = getObjectsAt(x, y, null);
        return lTemp.isEmpty();
    }
    
    /**
     *  Diese Methode überprüft ob ein bestimmtes Feld eine Mauer hat:
     *  x - x-index auf der x Achse im Zellenformat.
     *  y - y-index auf der y Achse im Zellenformat.
     *  
     *  Output : Ein Boolean ob das Feld besetzt ist oder nicht.
     *  true  - hat eine Mauer
     *  false - hat keine Mauer
     */
    public boolean hasBrickAt(int x, int y)
    {
        java.util.List lTemp = getObjectsAt(x, y, Brick.class);

        return !lTemp.isEmpty();
    }
    
    /**
     *  Diese Methode überprüft ob ein bestimmtes Feld ein Schaf hat:
     *  x - x-index auf der x Achse im Zellenformat.
     *  y - y-index auf der y Achse im Zellenformat.
     *  
     *  Output : Ein Boolean ob das Feld besetzt ist oder nicht.
     *  true  - hat ein Schaf
     *  false - hat kein Schaf
     */
    public boolean hasSheepAt(int x, int y)
    {
        java.util.List lTemp = getObjectsAt(x, y, Sheep.class);

        return !lTemp.isEmpty();
    }

    /**
     *  Diese Methode überprüft ob ein bestimmtes Feld Grass hat:
     *  x - x-index auf der x Achse im Zellenformat.
     *  y - y-index auf der y Achse im Zellenformat.
     *  
     *  Output : Ein Boolean ob das Feld besetzt ist oder nicht.
     *  true  - hat Gras
     *  false - hat kein Gras
     */
    
    public boolean hasGrassAt(int x, int y)
    {
        java.util.List lTemp = getObjectsAt(x, y, Grass.class);

        return !lTemp.isEmpty();
    }
    
    /**
     *  Diese Methode entfernt das Gras auf einem Feld. 
     *  x - x-index auf der x Achse im Zellenformat.
     *  y - y-index auf der y Achse im Zellenformat.
     */
    public void eatGrassAt(int x, int y)
    {
        java.util.List lTemp = getObjectsAt(x, y, Grass.class);

        if(!lTemp.isEmpty())
        {
            removeObject((Actor)lTemp.get(0));
        }
    }

    /**
     *  Diese Methode überprüft ob ein bestimmtes Feld von einem Schaf oder
     *  einer Mauer besetzt ist:
     *  x - x-index auf der x Achse im Zellenformat.
     *  y - y-index auf der y Achse im Zellenformat.
     *  
     *  Output : Ein Boolean ob das Feld besetzt ist oder nicht.
     *  true  - ist besetzt
     *  false - ist frei
     */
    public boolean hasSolidAt(int x, int y)
    {
        return hasBrickAt(x, y) || hasSheepAt(x, y);
    }
    

    /**
     * Bereitet die Welt vor (wird in der Methode public Field() aufgerufen).
     * 
     * Hier können Objekte wie Schafe oder weitere Tiere (Akteure hinzugefügt 
     * werden)
     */
    private void prepare()
    {
        // fügt ein Schaf in die Welt ein
        Sheep sheep1 = new Sheep();
        addObject(sheep1, 14, 16);
        
        // kannst du hier ein weiteres eigenes Schaf einfügen?
        // Sheep sheep2 = ...
        

    }
 }


